@@ -7,7 +7,7 @@
     - Call Terminal commands using python 3 (this one requires a nix machine)
 """
 
-__version__ = "0.2.7"
+__version__ = "0.2.8"
 __license__ = 'MIT'
 
 # from typing import *
@@ -18,7 +18,7 @@ from .javascript import *
 # from .terminal import *
 
 import requests
-
+import re
 
 class domonic:
 
@@ -59,37 +59,14 @@ class domonic:
         """ HTML as input and returns python """
 
         # NOTE - not working/finished.
-
         print("attempting to parse the page")
 
-        import re
-
         html = ''.join(html.split('<!DOCTYPE HTML>'))
         html = ''.join(html.split('<!doctype html>'))
 
         # html = "<html><body>some content</body></html>"
 
-        # htmltags = ["html", "span", "button", "link", "form", "nav",
-        #             "details", "summary", "header", "head", "body", "meta",
-        #             "title", "div", "footer", "img", "a", "p", "h1", "h2",
-        #             "h3", "h4", "h5", "h6", "hr", "ul", "ol", "li", "time",
-        #             "template", "label", "input", "small", "strong", "option",
-        #             "select", "main", "td", "tr", "thead", "th", "table",
-        #             "tbody", "canvas", "b", "center", "br"]
-
-        # htmltags = ["html", "body", "head", "script", "style", "h1", "h2", "h3", "h4", "h5", "h6", "p", "i", "b",
-        #             "a", "ul", "ol", "li", "hr", "div", "span", "strong", "blockquote",
-        #             "table", "tr", "td", "title", "meta", "form", "label", "submit", "title", "noscript",
-        #             "section", "nav", "article", "aside", "hgroup", "address", "pre", "dl", "dt", "dd", "figure",
-        #             "figcaption", "em", "small", "s", "cite", "q", "dfn", "abbr", "code", "var", "samp", "kbd", "sub",
-        #             "sup", "u", "mark", "ruby", "rt", "rp", "bdi", "bdo", "span", "ins", "iframe", "video", "audio",
-        #             "canvas", "caption", "colgroup", "tbody", "thead", "tfoot", "th", "fieldset", "legend", "button",
-        #             "select", "datalist", "optgroup", "option", "textarea", "output", "progress", "meter", "details",
-        #             "summary", "menu", "font", "header", "footer", "map", "object", "del", "time", "base", "link",
-        #             "meta", "hr", "br", "wbr", "img", "embed", "param", "source", "track", "area", "col", "input",
-        #             "keygen", "command", "main"]
-
-        htmltags = ["figcaption", "blockquote", "textarea", "progress", "optgroup", "noscript", "fieldset", "datalist", 
+        htmltags = ["figcaption", "blockquote", "textarea", "progress", "optgroup", "noscript", "fieldset", "datalist",
                     "colgroup", "summary", "section", "details", "command", "caption", "article", "address", "submit",
                     "strong", "source", "select", "script", "output", "option", "object", "legend", "keygen", "iframe",
                     "hgroup", "header", "footer", "figure", "canvas", "button", "video", "track", "title", "title",
@@ -97,8 +74,8 @@ class domonic:
                     "audio", "aside", "time", "span", "span", "samp", "ruby", "meta", "meta", "menu", "mark", "link",
                     "html", "head", "form", "font", "code", "cite", "body", "base", "area", "abbr", "wbr", "var", "sup",
                     "sub", "pre", "nav", "map", "main", "kbd", "ins", "img", "div", "dfn", "del", "col", "bdo", "bdi",
-                    "ul", "tr", "th", "td", "rt", "rp", "ol", "li", "hr", "hr", "h6", "h5", "h4", "h3", "h2", "h1", "em",
-                    "dt", "dl", "dd", "br", "u", "s", "q", "p", "i", "b", "a"]
+                    "ul", "tr", "th", "td", "rt", "rp", "ol", "li", "hr", "hr", "h6", "h5", "h4", "h3", "h2", "h1",
+                    "em", "dt", "dl", "dd", "br", "u", "s", "q", "p", "i", "b", "a"]
 
         for tag in htmltags:
             # print(tag)
